@@ -362,9 +362,9 @@ class DataTransformer(MPTTModel):
 
 class DataTransformerConstants(models.Model):
     id = models.UUIDField(primary_key=True, default=uuid.uuid4,blank=True,null=False)
-    data_transformer = models.ForeignKey(DataTransformer, related_name='data_transformer_constants', on_delete=models.CASCADE, blank=True, null=True)
+    data_transformer = models.ForeignKey(DataTransformer, related_name='data_transformer_constants', on_delete=models.CASCADE, blank=False, null=False)
     index = models.IntegerField(blank=True, null=True, default=None)
-    value = models.FloatField(blank=True,null=False)
+    value = models.FloatField(blank=False,null=False)
     updated_at = models.DateTimeField(auto_now=True)
     created_at = models.DateTimeField(auto_now_add=True)
 
