@@ -213,7 +213,7 @@ class HardwareIOSerializer(serializers.ModelSerializer):
 
 
 class DataTransformerConstantsSerializer(serializers.ModelSerializer):
-    data_transformer = serializers.PrimaryKeyRelatedField(read_only=True)
+    data_transformer = serializers.PrimaryKeyRelatedField()
 
     class Meta:
         model = DataTransformerConstants
@@ -223,8 +223,8 @@ class DataTransformerConstantsSerializer(serializers.ModelSerializer):
 
 class DataTransformerTreeSerializer(serializers.ModelSerializer):
     data_transformer_constants = DataTransformerConstantsSerializer(many=True)
-    channels = serializers.PrimaryKeyRelatedField(read_only=True,many=True)
-    channel_stats = serializers.PrimaryKeyRelatedField(read_only=True,many=True)
+    channels = serializers.PrimaryKeyRelatedField(many=True)
+    channel_stats = serializers.PrimaryKeyRelatedField(many=True)
 
     children = serializers.SerializerMethodField(source='get_children')
     class Meta:
